@@ -53,7 +53,7 @@ def Serve(servicer):
     plugin_pb2_grpc.add_ControllerServicer_to_server(servicer, server)
     health_pb2_grpc.add_HealthServicer_to_server(health, server)
     port = defaultPort
-    while:
+    while True:
         srv_str = f'127.0.0.1:{port}'
         try:
             server.add_insecure_port(srv_str)
